@@ -4,6 +4,16 @@ from sklearn.neighbors import KNeighborsRegressor
 from sklearn.neighbors import KNeighborsClassifier
 
 from itproject.machinelearning.KNNRegressor import KNNRegressor
+from sklearn.tree import DecisionTreeClassifier
+from sklearn.tree import DecisionTreeRegressor
+# 随机森林 回归
+from sklearn.ensemble import RandomForestClassifier
+from sklearn.ensemble import RandomForestRegressor
+# 支持向量机 分类
+from sklearn.svm import SVC
+# 支持向量机 回归
+from sklearn.svm import SVR
+from sklearn.tree import plot_tree
 from itproject.utils import DataUtil, ChartUtil, AnalyseUtil
 
 knn_regressor = KNeighborsRegressor()
